@@ -1,6 +1,5 @@
+#![forbid(unsafe_code)]
 #![deny(
-    warnings,
-    unsafe_code,
     missing_docs,
     clippy::missing_docs_in_private_items
 )]
